
A Python implementation of gnomic, currently in development.





Development
-----------

To rebuild the gnomic parser using `grako`, run:

::

    grako genotype.enbf -o gnomic/grammar.py -m Gnomic